@@ -1,3 +1,4 @@
+from .base import BaseModel
 from .pengguna import Pengguna
 from .peserta_didik import PesertaDidik
 from .ptk import Ptk
@@ -5,6 +6,7 @@ from .rombongan_belajar import RombonganBelajar
 from .sekolah import Sekolah
 
 __all__ = [
+    "BaseModel",
     "Pengguna",
     "PesertaDidik",
     "Ptk",
