@@ -1,8 +1,9 @@
-from dataclasses import dataclass
+from dapodik_webservice.converter import dataclass
+from .. import BaseModel
 
 
 @dataclass
-class AnggotaRombel:
+class AnggotaRombel(BaseModel):
     anggota_rombel_id: str
     peserta_didik_id: str
     jenis_pendaftaran_id: str
